import os
from dotenv import load_dotenv, find_dotenv

load_dotenv(find_dotenv())


def log_to_console(level, prog_info, message):
    # ERROR = 1, INFO = 2, DEBUG = 3
    if int(os.getenv('LOG_LVL')) > 0 and level == 'ERROR':
        print(level, prog_info, message)
    if int(os.getenv('LOG_LVL')) > 1 and level == 'INFO':
        print(level, prog_info, message)
    if int(os.getenv('LOG_LVL')) > 2 and level == 'DEBUG':
        print(level, prog_info, message)



from setuptools import setup, find_packages

with open("README.md", "r", encoding = "utf-8") as fh:
    long_description = fh.read()

setup(
    name = "smartez-logger",
    version = "0.0.6",
    author = "Rune Lykke-Kjeldsen",
    author_email="rune@lykke-kjeldsen.dk",
    description = "Logger package used for smartez",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    python_requires = ">=3.7",
    url = "https://github.com/BispensGipsGebis/smartez-logger",
    classifiers = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir = {"": "src"},
    packages = find_packages(where="src"),
    project_urls={
    "Bug Tracker": "https://github.com/BispensGipsGebis/smartez-logger/issues",
    }
)